@@ -50,7 +50,7 @@ class DocumentSearch extends CMSModule
 
   function GetVersion()
   {
-    return '1.4.4';
+    return '1.4.5';
   }
 
   function GetHelp()
@@ -107,7 +107,7 @@ class DocumentSearch extends CMSModule
     return $this->Lang('dash_record_count',$rcount);
   }
 
-  function DisplayErrorPage($id, &$params, $return_id, $message='')
+  function DisplayErrorPage($id, $params, $return_id, $message='')
     {
 		$this->smarty->assign('title_error', $this->Lang('error'));
 		$this->smarty->assign_by_ref('message', $message);
@@ -250,7 +250,7 @@ class DocumentSearch extends CMSModule
 	}
 
 
-	function SearchReindex(&$module) {
+	function SearchReindex($module) {
 		$db = cmsms()->GetDb();
 
 		$query = 'SELECT * FROM '.cms_db_prefix().'module_documentsearch ORDER BY documentsearch_id';
